h1_binding_factor

Function h1_binding_factor 

pub fn h1_binding_factor(rho_input: &[u8]) -> Scalar
H1 — the binding factor rho. Output: a scalar mod ℓ.

The spec encodes a structured input (a “rho input” prefix). For our signing scheme the binding factor input is the concatenation of the message and the sorted list of (party_index, D_i, E_i) commitments.